@@ -1,6 +1,5 @@
 """Object-specific python package to run automated tasks in the Chase Lab."""
 
-from .recycle import fwarnings, trials, trials_abv
 from .ffsync import ffsync
 from .ffconcat import ffconcat
 from .lazytrim import lazytrim
@@ -8,6 +7,7 @@ from .improve_dlc_output import improve_dlc_output
 from .improve_dlc_csv import improve_dlc_csv
 from .improve_dlc_output_cat_alone import improve_dlc_output_cat_alone
 from .csv2h5 import csv2h5
+from .recycle import *
 from .analyze_rois import analyze_rois
 from .concat_rois import concat_rois
 from .roi_calc_mw import roi_calc_mw
