@@ -1,6 +1,7 @@
 import pandas as pd
 from numpy import mean
 import json
+from toxopy import trials
 
 
 def jsonify_dlc_avgs(csv_file):
@@ -14,11 +15,7 @@ def jsonify_dlc_avgs(csv_file):
 
     cats = df.cat.unique()
 
-    trials = [
-        'No treatment', 'Cat alone (1)', 'First Saline', 'Cat alone (2)',
-        'First Urine', 'Cat alone (3)', 'Second Saline', 'Cat alone (4)',
-        'Second Urine', 'Cat alone (5)'
-    ]
+    tls = trials()
 
     d = {}
 
@@ -27,7 +24,7 @@ def jsonify_dlc_avgs(csv_file):
         df2 = df.loc[(df['cat'] == cat)]
         d[cat] = {}
 
-        for t in trials:
+        for t in tls:
             df3 = df2.loc[(df['trial'] == t)]
             d[cat][t] = {}
             d[cat][t]['distance'] = mean(df3['distance_loess05'])
