@@ -1,11 +1,12 @@
 import warnings
 
+
 def fwarnings():
 
     return warnings.filterwarnings("ignore")
 
 
-def trials():
+def trials_full():
 
     return [
         'no treatment', 'cat alone (1)', 'first saline', 'cat alone (2)',
@@ -13,6 +14,7 @@ def trials():
         'second urine', 'cat alone (5)'
     ]
 
-def trials_abv():
-    
-    return ['FT', 'CA1', 'ST1', 'CA2', 'UT1', 'CA3', 'ST2', 'CA4', 'UT2', 'CA5']
\ No newline at end of file
+
+def trials():
+
+    return ['FT', 'CA1', 'ST1', 'CA2', 'UT1', 'CA3', 'ST2', 'CA4', 'UT2', 'CA5']
