@@ -1,5 +1,6 @@
 from scipy.stats import mannwhitneyu
 import pandas as pd
+from toxopy import trials
 
 
 def roi_calc_mw(data_file, voi):
@@ -8,17 +9,13 @@ def roi_calc_mw(data_file, voi):
 
     df = pd.read_csv(data_file)
 
-    trial_names = [
-        'No treatment', 'Cat alone (1)', 'First Saline', 'Cat alone (2)',
-        'First Urine', 'Cat alone (3)', 'Second Saline', 'Cat alone (4)',
-        'Second Urine', 'Cat alone (5)'
-    ]
+    tls = trials()
 
     for j in ['walls', 'middle']:
 
         print('\n', j)
 
-        for i in trial_names:
+        for i in tls:
 
             positive = df.loc[(df['trial'] == i)
                               & (df['infection_status'] == 'Positive') &
